@@ -5,8 +5,8 @@
  *      Author: jeremy
  */
 
-#ifndef SOURCE_API_CONFIG_CONFIG_API_HPP_
-#define SOURCE_API_CONFIG_CONFIG_API_HPP_
+#ifndef LIBEXADRUMS_API_CONFIG_CONFIG_API_HPP
+#define LIBEXADRUMS_API_CONFIG_CONFIG_API_HPP
 
 #include "Config_api.h"
 
@@ -30,6 +30,16 @@ namespace eXaDrumsApi
 		Util::ErrorToException([&] { return this->LoadTriggersConfig_(); });
 	}
 
+	inline void Config::LoadSpiDevConfig() const
+	{
+		Util::ErrorToException([&] { return this->LoadSpiDevConfig_(); });
+	}
+
+	inline void Config::SaveSpiDevConfig()
+	{
+		Util::ErrorToException([&] { return this->SaveSpiDevConfig_(); });
+	}
+
 	inline void Config::SaveCurrentAudioDeviceConfig() const
 	{
 		Util::ErrorToException([&] { return this->SaveCurrentAudioDeviceConfig_(); });
@@ -89,6 +99,11 @@ namespace eXaDrumsApi
 		return;
 	}
 
+	inline void Config::SetSerialPort(const std::string& port) noexcept
+	{
+		SetSerialPort_(port.c_str());
+	}
+
 	inline void Config::SetAudioDeviceParameters(const AlsaParamsApi& params)
 	{
 
@@ -105,6 +120,11 @@ namespace eXaDrumsApi
 		return;
 	}
 
+	inline void Config::SetSpiDevParameters(const std::vector<SpiDevParameters>& params)
+	{
+		SetSpiDevParameters_(params.data(), params.size());
+	}
+
 	inline void Config::SetTriggerParameters(int triggerId, const TriggerParameters& params)
 	{
 		SetTriggerParameters_(triggerId, params);
@@ -186,12 +206,43 @@ namespace eXaDrumsApi
 		return vec;
 	}
 
+	inline std::vector<std::string> Config::GetSupportedSpiDevices()
+	{
+		unsigned int size{};
+		GetSupportedSpiDevices_(nullptr, size);
+
+		std::vector<const char*> data(size);
+		GetSupportedSpiDevices_(data.data(), size);
+
+		std::vector<std::string> v(size);
+		std::copy(data.cbegin(), data.cend(), v.begin());
+
+		return v;
+	}
+
 	inline AlsaParamsApi Config::GetAudioDeviceParams() const noexcept
 	{
-
 		return GetAudioDeviceParams_();
 	}
 
+
+	inline std::vector<SpiDevParameters> Config::GetSpiDevicesParameters() const
+	{
+
+		unsigned int size = 0;
+		GetSpiDevicesParameters_(nullptr, size);
+
+		std::vector<SpiDevParameters> vec;
+		vec.reserve(size);
+		for(size_t i = 0; i < size; ++i)
+		{
+			vec.emplace_back("", -1, -1);
+		}
+		GetSpiDevicesParameters_(vec.data(), size);
+
+		return vec;
+	}
+
 	inline std::string Config::GetSensorsType()
 	{
 		return std::string(GetSensorsType_());
@@ -202,6 +253,11 @@ namespace eXaDrumsApi
 		return std::string(GetSensorsDataFolder_());
 	}
 
+	inline std::string Config::GetSerialPort() const noexcept
+	{
+		return std::string{GetSerialPort_()};
+	}
+
 
 	inline std::string Config::GetAudioDeviceName() const noexcept
 	{
@@ -213,4 +269,4 @@ namespace eXaDrumsApi
 
 
 
-#endif /* SOURCE_API_CONFIG_CONFIG_API_HPP_ */
+#endif /* LIBEXADRUMS_API_CONFIG_CONFIG_API_HPP */
