@@ -5,8 +5,8 @@
  *      Author: jeremy
  */
 
-#ifndef SOURCE_API_CONFIG_TRIGGERPARAMETERS_API_H_
-#define SOURCE_API_CONFIG_TRIGGERPARAMETERS_API_H_
+#ifndef LIBEXADRUMS_API_CONFIG_TRIGGERPARAMETERS_API_H
+#define LIBEXADRUMS_API_CONFIG_TRIGGERPARAMETERS_API_H
 
 
 namespace DrumKit { struct TriggerParameters; }
@@ -39,4 +39,4 @@ namespace eXaDrumsApi
 
 }
 
-#endif /* SOURCE_API_CONFIG_TRIGGERPARAMETERS_API_H_ */
+#endif /* LIBEXADRUMS_API_CONFIG_TRIGGERPARAMETERS_API_H */
