@@ -11,6 +11,7 @@
 #include "ISensor.h"
 
 #include <atomic>
+#include <memory>
 
 namespace IO
 {
@@ -19,14 +20,18 @@ namespace IO
 
 	public:
 
-		VirtualSensor() { is_digital = true; }
-		virtual ~VirtualSensor() {}
+		VirtualSensor(size_t chan) 
+		{ 
+			isDigital = true; 
+			channel = chan;
+		}
+		virtual ~VirtualSensor() = default;
 
-		virtual short GetData(char channel) final
+		virtual short GetData() final
 		{
 			return data.exchange(0, std::memory_order_acquire);
 		}
-		virtual void SetData(char channel, short value) final
+		virtual void SetData(short value) final
 		{
 			data.store(value, std::memory_order_release);
 		}
@@ -35,6 +40,9 @@ namespace IO
 
 		std::atomic<short> data{};
 	};
+
+	using VirtualSensorPtr = std::unique_ptr<VirtualSensor>;
+
 }
 
 #endif /* IO_VIRTUALSENSOR_H_ */
